@@ -88,6 +88,8 @@ def parse(html: str, p: Product, include: Sequence = None):
     "category" in include and parse_category(p, selector=sel)
     "date_first_avail" in include and parse_date_first_avail(p, selector=sel)
     "customize" in include and parse_customize(p, html=html)
+    "images" in include and parse_images(p, selector=sel)
+    "aplus" in include and parse_aplus(p, selector=sel)
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
@@ -499,3 +501,30 @@ def parse_date_first_avail(p: Product, selector: parsel.Selector = None):
 
 def parse_customize(p: Product, html: str = None):
     p.customize = "This product needs to be customized before adding to cart." in html
+
+
+def parse_images(p: Product, selector: parsel.Selector = None):
+    images = selector.re_first(r"'colorImages': { 'initial': (\[.*\])},")
+    if images is None:
+        p.images = None
+        return
+
+    images = re.findall(r'"main":{.*?}', images)
+    if len(images) == 0:
+        p.images = None
+        return
+
+    images_urls = list()
+    for image in images:
+        urls = re.findall(r'"(https.*?)"', image)
+        if len(urls) > 0:
+            images_urls.append(urls[-1])
+
+    if len(images_urls) == 0:
+        p.images = None
+    else:
+        p.images = images_urls
+
+
+def parse_aplus(p: Product, selector: parsel.Selector = None):
+    p.aplus = len(selector.xpath("//*[@id='aplus']")) > 0
